GENCCODE_ASSEMBLY_TYPE=-a gcc
SO=so
SOBJ=so
A=a
LIBPREFIX=lib
LIB_EXT_ORDER=.71.1
COMPILE=microblazeel-xilinx-linux-gcc  -mlittle-endian -mxl-barrel-shift -mxl-pattern-compare -mxl-reorder -mcpu=v11.0 -mno-xl-soft-mul -mxl-multiply-high -mno-xl-soft-div -mhard-float   -D_REENTRANT  -DU_HAVE_ELF_H=1 -DU_HAVE_STRTOD_L=1 -DU_HAVE_XLOCALE_H=0  -DU_ATTRIBUTE_DEPRECATED= -O2 -pipe -g -feliminate-unused-debug-types  -std=c11 -Wall -pedantic -Wshadow -Wpointer-arith -Wmissing-prototypes -Wwrite-strings   -c
LIBFLAGS=-I/usr/include -DPIC -fPIC
GENLIB=microblazeel-xilinx-linux-gcc  -mlittle-endian -mxl-barrel-shift -mxl-pattern-compare -mxl-reorder -mcpu=v11.0 -mno-xl-soft-mul -mxl-multiply-high -mno-xl-soft-div -mhard-float   -O2 -pipe -g -feliminate-unused-debug-types  -std=c11 -Wall -pedantic -Wshadow -Wpointer-arith -Wmissing-prototypes -Wwrite-strings   -Wl,-O1      -shared -Wl,-Bsymbolic
LDICUDTFLAGS=
LD_SONAME=-Wl,-soname -Wl,
RPATH_FLAGS=
BIR_LDFLAGS=-Wl,-Bsymbolic
AR=microblazeel-xilinx-linux-gcc-ar
ARFLAGS=r
RANLIB=microblazeel-xilinx-linux-gcc-ranlib
INSTALL_CMD=install -c
